fhs_xmltv_tools
===============


I wanted to know more about the xmltv xml file i downloaded for my iptv and i wanted to know how it all worked.
So i am startig to create my own tools



Usage
-----

Installation
------------

.. code-block:: bash

  git clone https://github.com/foxhunt72/fhs-m3u2strm
  cd fhs-m3u2strm
  pip3 install .

  # And in the future also

  pipx install fhs_m3u2strm
  or
  pip3 install fhs_m3u2strm


Requirements
^^^^^^^^^^^^
- typer[all]
- py-xmltv

Compatibility
-------------


Licence
-------
MIT Licencse

Authors
-------
Richard de Vos

`fhs_xmltv_tools` was written by `Richard de Vos <rdevos72@gmail.com>`_.
